#
# spec file for package gnugk
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnugk
Version:        4.2
Release:        6.25
Summary:        OpenH323 Gatekeeper--The GNU Gatekeeper
License:        GPL-2.0+
Group:          Productivity/Telephony/H323/Servers
Url:            http://www.gnugk.org
Source0:        http://prdownloads.sourceforge.net/openh323gk/%{name}-%{version}-2.tar.gz
Source2:        %{name}.service
BuildRequires:  SDL-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  h323plus-devel
BuildRequires:  krb5
BuildRequires:  libdv
BuildRequires:  libpt-devel
BuildRequires:  libtool
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  sgml-skel
BuildRequires:  sgmltool
BuildRequires:  speex-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libsasl2)
Requires(pre):  diffutils
Requires(pre):  grep
Recommends:     logrotate
%{?systemd_requires}

%description
The gatekeeper controls H.323 compatible clients (like ohphone) and can
be used to set up a complete Internet telephony system.

%prep
%setup -q

%build
%configure \
	--disable-mysql \
	--disable-pgsql \
    OPENH323DIR=%{_prefix}
make RPM_OPT_FLAGS="%{optflags}" opt %{?_smp_mflags}
make RPM_OPT_FLAGS="%{optflags}" doc %{?_smp_mflags}

%install
export M=`uname -m`
# only ix86 have problematic unames.
case $M in
  ??86) M=x86
  ;;
  armv7l) M=armv7hl
  ;;
esac
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_localstatedir}/log/gk
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -m 755 obj_linux_"$M"/gnugk %{buildroot}%{_sbindir}
#install -m 755 obj_linux_"$M"/addpasswd %{buildroot}%{_sbindir}/gkaddpasswd
install -m 644 etc/complete.ini %{buildroot}%{_sysconfdir}/gnugk.ini
mkdir -p %{buildroot}/%{_mandir}/man1
install -m 644 docs/gnugk.1 %{buildroot}/%{_mandir}/man1/gnugk.1
# Create symbolic run level links during installation
cat << EOF > %{buildroot}%{_sysconfdir}/logrotate.d/gnugk
%{_localstatedir}/log/gk/gk.log {
    rotate 30
    size=100M
    notifempty
    missingok
    postrotate
        systemctl try-restart %{name}.service
    endscript
}
EOF
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

rm -f CMakeLists.txt

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root)
%doc *.txt
%{_mandir}/man1/gnugk.1.gz
%doc docs/manual/*.html
%doc etc/*
%config %{_sysconfdir}/gnugk.ini
%{_sbindir}/gnugk
%{_sbindir}/rcgnugk
%{_sysconfdir}/logrotate.d/gnugk
%{_localstatedir}/log/gk
%{_unitdir}/%{name}.service

%changelog
* Fri Jul 15 2016 p.drouand@gmail.com
  Update to version 4.2 (boo#777486, CVE-2012-3534)
  * BUGFIX(ProxyChannel.cxx) fix H.239 forwarding issue in call
    where only one side uses H.460.19
  * BUGFIX(configure.in) make sure LUA test fails for versions below 5.2
  * BUGFIX(gkh235.cxx) small fix with password auth
  * BUGFIX(ProxyChannel.cxx) apply codec filtering also to
    receiveAndTransmit capabilities
  * BUGFIX(ProxyChannel.cxx) fix crash in RTP multiplexing
  * BUGFIX(ProxyChannel.cxx) fix crash when using H.245 tunneling translation
  * BUGFIX(gk.cxx) fix shutdown on NetBSD 7
  * BUGFIX(ProxyChannel.cxx) fix compile on NetBSD 7
  * new switch: [RoutedMode] FilterVideoFastUpdatePicture= to reduce
    the number of update requests from endpoints
  * disable SSLv3 when using TLS
  * BUGFIX(ProxyChannel.cxx) fix crash in call cleanup
  * support ON and OFF event in LuaAcct
  * BUGFIX(sqlacct.*) implement ON and OFF event as documented
  * new switches [RoutedMode] EnableGnuGkNATTraversal=1 and
    [Endpoint] EnableGnuGkNATTraversal=1 to keep GnuGk's old NAT
    traversal method enabled
- Changes from version 4.0
  * BUGFIX(ProxyChannel.cxx) fix crash processing Setup
  * BUGFIX(RasSrv.cxx) update IP/port of traversal neighbor on every SCI,
    not only on IP changes
  * new status port command: PrintNeighbors
  * BUGFIX(ProxyChannel.cxx) fix H.239 inside multiplePayloadStream
    from Avaya XT5000 with H.460.19
  * new accounting module: LuaAcct
  * LUA: new library "gnugk" to allow access to GnuGk functionality
  * BUGFIX(configure) set all detected options in gnugkbuildopts.h
    on Unix
  * BUGFIX(ProxyChannel.cxx) removing H.235 capabilities might have
    skipped items
  * BUGFIX(lua.cxx) initialize all LUA variables for LUA routing
  * status port configuration (MaxStatusClients, StatusEventBacklog,
    StatusEventBacklogRegex) now
  changable at runtime
  * BUGFIX(GkStatus.cxx) fix StatusEventBacklogRegex for patterns that
    start at the beginning of the event line
  * BUGFIX(ProxyChannel.cxx) use RealPresence Group 0  *Byte keep  *alive for
  IgnoreSignaledH239PrivateIPs (needs LARGE_FDSET to work)
  * new switches to set database connect and read timeout (only used by
    MySQL for now)
  * new switch to set worker thread idle timeout:
    [Gatekeeper::Main] WorkerThreadIdleTimeout=
  * BUGFIX(gk.cxx) better test for gatekeeper shutdown
  * BUGFIX(Routing.cxx) fix fromIP for ARQ and LRQ RouteRequests
  * BUGFIX(gkauth.cxx) only call Q.931 checks when activated
  * BUGFIX(Routing.cxx) fix RouteRequest from unregistered caller
    who doesn't provide any alias
  * new switch: [RoutedMode] DisableSettingUDPSourceIP=1
- Perform a spec-cleaner on the spec file
* Fri Dec 11 2015 p.drouand@gmail.com
- Update to version 4.0
  * rewrite of the H.235 password authentication - much better
    interoperability and much more secure
  * IP authentication for all RAS and Q.931 messages
  * important IPv6 updates and fixes
  * support for TCS0 call transfers ("reroute") that can be initiated
    from applications
  * better NAT traversal support for unregistered endpoints
  * better blocking of spam calls using SQLAuth
  * per endpoint codec filtering
  * DisplayIE rewriting
  * more secure handling of status port passwords (only hash stored)
  * important fix for ODBC database driver
  * CalledPartyNumber IE rewriting for better Polycom interoperability
  * bug fixes
- Changes from version 3.9
  * bug fixes, including a crash and hanging status port on Windows servers
  * a new IP/port detection algorithm for endpoints behind NAT that works
    well even with unregistered (!) endpoint
  * neighbor pings to speed up call routing if your neighbors are frequently down
  * geo-blocking: with the GeoIPAuth policy, you can allow or block calls based
    on the location of the IP
  * status port event back log: When you connect to the status port to
    diagnose an issue, the relevant events are already gone. With this
    new feature you can tell GnuGk to save the last n events and show
    them later on. This way you can take a look at eg. the last 100
    failed registrations etc.
  * QoS DiffServ marking for RAS, H.225 and H.245 messages. Now you can
    set the DiffServ class for signaling messages. Previously you could
    only mark RTP packets.
  * support for H.235.TSSM: H.235 needs time synchronization between
    gatekeeper and endpoints and the proposed H.235.TSSM standard provides
    a means for endpoints to detect that they are not in sync with the
    gatekeeper and apply a time offset.
- Remove gnugk-fix-h323plus-directory.patch; fixed on upstream
  release
* Thu Sep 17 2015 p.drouand@gmail.com
- Update to version 3.8
  * BUGFIX(GkSTatus.cxx) fix crash in shutdown during Reload
  * allow codec filtering for whole capability classes, eg.
    DisableCodecs=receiveVideoCapability
  * BUGFIX(lua.cxx) fix crash in 'lua' routing policy
  * BUGFIX(RasTbl.cxx) fix [EP::] ForceGateway= to work with
    permanent endpoints
  * make [Gatekeeper::Main] Authenticators= switch case insensitive
  * addpasswd encodes password, even if the config section didn't
    exist before
  * FileIPAuth now supports checking ARQs
  * new switch [Gatekeeper::Main] MinH323Version=
  * BUGFIX(RasTbl.cxx) stop generating predictable endpoint IDs
  * new switch [RasSrv::ARQFeatures] CheckSenderIP=1
  * new SQLAuth variable %%{SrcInfo}
  * BUGFIX(gkauth.cxx,Neighbor.cxx) use OpenSSL for cryptographically
    relevant random numbers
  * BUGFIX(RasTbl.cxx) only apply [EP::] AddNumbers= if the endpoint
    doesn't have the number already
  * BUGFIX(RasTbl.cxx) fix error message for permanent gateways on
    config reload
  * BUGFIX(Routing.cxx) CatchAll policy now rewrites the destination
    alias to the CatchAll alias
  * new authentication modules using LUA scripts: LuaAuth
  * BUGFIX(gkauth.cxx) ignore port in AliasAuth rules when endpoint
    is using H.460.18
  * extend PrefixAuth to support unregistered calls
  Please read the changes.txt file for previous changes
- Drop sysvinit support; doesn't build for old platforms
- Add gnugk-fix-h323plus-directory.patch
- Add dependencies following upstream changes
  * openssl-devel
  * pkgconfig(libsasl2)
  * pkgconfig(expat)
  * pkg-config
- Add autoconf and libtools dependencies; needed because of
  gnugk-fix-h323plus-directory.patch
- Move from openh323-devel to h323plus-devel and pwlib-devel
  to libpt-devel
- Increase dependencies weight; require systemd-rpm-macros instead
  of pkgconfig(systemd)
- Use download Url as source
* Fri May 31 2013 crrodriguez@opensuse.org
- Add systemd support.
* Mon Aug 20 2012 dmueller@suse.com
- fix build on armv7l
* Sat Dec 10 2011 meissner@suse.de
- does not need openldap2 binaries, just the libs
* Fri Dec  2 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Nov  7 2007 kkeil@suse.de
- update to stable 2.2.6
  * BUGFIX(toolkit.cxx) Fixed DefaultDomain Alias rewrite
  * BUGFIX(routing.cxx) ENUM policy not to be used with LRQ
  * BUGFIX(Neighbors.cxx) Fixed SRV policy to try both CS and LR
    records and not use with LRQ request
  * remove ArjReasonRouteCallToSCN
    (was inactive + broken for a long time)
  * BUGFIX(Toolkit.cxx) enable SQLConfig also if only Firebird is
    available
  * BUGFIX(RasTbl.cxx) reject the call if no gateway has capacity,
    don't just use the first matching gateway
  * BUGFIX(RasTbl.cxx) the first route was duplicated and a call
    was sent twice to the same gw.
    Thanks to Alex Golyshev for pointing this out!
  * BUGFIX(RasSrv.cxx) fixed crash inside IRR handler
  * BUGFIX(yasocket.cxx) due to recent changes, it was impossible
    send more than 10240 bytes of data when data queuing had to be
    involved
  * move status port examples to contrib/statusport/
  * fix nonStandardData field usage, make use of assigned
    T.35 codes
  * BUGFIX(RasTbl.cxx) ensure that full gateways are eliminated,
    when failover is active and remaining gateways are sorted due
    to their priority correctly
  * BUGFIX(ProxyChannel.cxx) preserve presentation and screening
    indicators in Calling-Party-Number IEs
  * BUGFIX(RasTbl.cxx) restore default value for capacity and
    priority on config reload, if removed from an EP section
    (or if the whole section has been removed)
  * BUGFIX(Neighbor.cxx,ProxyChannel.cxx): fix canMapAlias for LRQs
    with unregistered endpoints
  * new config section [H225toQ931] to change the H.225 reason to
    Q.931 cause code mapping
  * optional priorities for gateway prefixes:
    gw-alias=prefix[:=priority][,prefix[:=priority],...]
    (patch by Alex Golyshev and Andrey Pasukov)
  * change default value for CallSignalHandler to 5
  * BUGFIX(Toolkit.cxx): fix for calling between 2 internal
    networks
  * Added AcceptNonNeighborLCF to LRQFeatures settings
  * Added GnuGk OID & T.35 Codes
  * BUGFIX(Toolkit.cxx): fix to allow URI rewriting on ARQ
    processing
  * BUGFIX(ProxyChannel.cxx): fix to show correct Setup
    CallSignallingAddress when behind NAT
  * Added RemoveH235Call & RemoveH460Call Settings
  * BUGFIX(ProxyChannel.cxx): H.245 addresses being incorrectly
    written in NATHandler for public proxies.
* Sat May 12 2007 olh@suse.de
- remove unused libavc1394-devel libdc1394-devel from Buildrequires
* Mon Feb 26 2007 kkeil@suse.de
- update to 2.2.5
  * RADIUS AAA module now handles a Class attribute correctly
  * BUGFIX(clirw.cxx) missing iterator check, that could cause an
    invalid memory access, fixed - thanks to Vladimir Voronin
  * implement optional call-id parameter for Routing commands
  * Bugfix(RasSrv.cxx) fix SignalCallID=1
  * Bugfix(Proxychannel.cxx) avoid inserting same socket twice in
    cleanup list
  * Bugfix(Proxychannel.cxx) make sure all members of
    CallSignalSocket are initialized on creation
  * Bugfix(yasocket.cxx) send very large status port messages
    in 10KB chunks and sleep after each
  * new feature: StatusPort filtering by Doron Bleiberg
  * new switch: [RoutedMode]DisableRetryChecks retries all calls
  * BUGFIX(ProxyChannel.cxx) make sure we preserve the original
    Setup message for retries and not only copy the buffer address
  * Bugfix(Neighbor.cxx) copy canMapAlias when forwarding LRQs
  * implement virtual queues for LRQs sponsored by Associated
    Engineering Srl.
  * implement canMapAlias for LCFs sponsored by TelecomUnity Ltd.
  * copy all unknown IEs in Notify messages when forwarding
    (fixes some failed transfers)
  * BUGFIX(*.cxx) set all deleted pointers to NULL
  * new SyslogAcct accounting module for the Unix syslog
  * (gkauth.cxx)Reapplied H235.1 (formally known as H235AnnexA)
    by using OpenH323 Authenticator factory loader
  * (rassrv.cxx)Registration Priority Added
  * (Proxychannel.cxx)TreatUnregisteredNat added. Treat
    unregistered calls unknown NAT status as being NAT
  * (routing.cxx)DNS SRV support to DNS Routing policy
  * (toolkit.cxx)RewriteAlias section added
  * BUGFIX(ProxyChannel.cxx) WaitAndSignal added to OnInformation
    to avoid NAT support crash.
  * BUGFIX(ProxyChannel.cxx) Check for NATSupport added.
  * BUGFIX(RasTbl.cxx) WaitAndSignal added to FindByEndPointid()
  * BUGFIX(ProxyChannel.cxx) Added SupportCallingNATedEndpoints.
  * Moved DNS SRV to it's own seperate policy
  * Registration pre-emption support added
  * Support for EP's on dynamic IP's
  * fixed code to compile with the latest pwlib CVS
    (STL string conversion)
  * Added support for GnuGK to work behind NAT box
  * Added support for Third party (non-neighbor) Gatekeepers
    (AcceptNonNeighborLRQ=1)
  * Added auto-detection on internal network for proxy mode.
  * Added DefaultDomain for H323 URI rewriting
* Thu Aug 10 2006 kkeil@suse.de
- fixes for pwlib 1.11.1
- update to 2.2.4
  * new Calling/CalledTypeOfNumber and Proxy configuration variables
    in [RouteMode] section and endpoint configuration. Thanks to Vladimir Voronin
  * (ipauth.cxx) added support for prefixes. Thanks to Vladimir Voronin
  * (gksql_firebird.cxx) Firebird/Interbase driver for SQL modules. Sponsored
    by Roitel Telecommunication S.A.
  * (Routing.cxx) NumberAnalysis routing policy can handle Setup messages now.
    Thanks to Vladimir (vl@kamatele.com)
  * (pwlib_compat.h) adapt to changed mutexes starting with PWLib 1.9.2
  * call mute in proxy mode using userinput * (patch by Simon Horne)
  * NAT support for unregistered callers (patch by Simon Horne)
  * (gk.cxx) allow correct spelling for FortyTwo=42 entry
  * BUGFIX(yasocket.h) fix compilation with gcc 4.1
  * (clirw.cxx) process CLI ranges with leading zeros correctly
  * new CapacityControl auth/acct modules to control inbound traffic
  * BUGFIX(ProxyChannel.cxx) check added for a NULL pointer in NAT traversal code
  * (RasTbl.cxx) default SignalTimeout value increased from 15 to 30 seconds
  * BUGFIX(RasSrv.cxx) remove call records correctly in direct signaling mode,
    when only called party is registered. Thanks to Julius Bajzik
  * BUGFIX(RasTbl.cxx) fixed race condition when accessing endpoint records
  * BUGFIX(ProxyChannel.cxx) fixed race condition in H245Socket when H.245
    tunneling is disabled
  * (configure) better detection of PostgreSQL on FreeBSD
  * BUGFIX(RasSrv.cxx) allow bandwidth=0 in ARQ / ACF
  * BUGFIX(ProxyChannel.cxx) fix bug when using RADIUS/SQL based routing
    for Setup messages
  * BUGFIX(ProxyChannel.cxx) check for poor NAT implementations, that might
    have crashed GnuGk (by Simon Horne)
  * new accounting variables: %%{media-oip}, %%{codec}
  * new accounting variables: %%{call-attemps}, %%{last-cdr}, %%{caller/callee-epid}
  * new feature: call failover (see manual)
  * BUGFIX(clirw.cxx) set presentationIndicator correctly in H.225.0 Setup UUIE
  * BUGFIX(RasTbl.h) when active, perform IRR checks for local
    endpoints only, others (parent, neighbor etc.) won't send us IRRs
  * BUGFIX(Routing.cxx) remove leading zeros for ENUM queries
  * BUGFIX(RasSrv.cxx) have AcceptNeighborsCalls default to 1 like
    the documentation always said
  * BUGFIX(Routing.cxx) fix ENUMPolicy implementation
  * new StatusAcct accounting module for the status port sponsored by Grupo Isec
* Mon May  1 2006 kkeil@suse.de
- install man page (#171056)
* Thu Apr  6 2006 hvogel@suse.de
- define operation on "buf1ptr" [#159102]
* Fri Jan 27 2006 nadvornik@suse.cz
- fixed BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Mon Oct 24 2005 kkaempf@suse.de
- update to 2.2.3-2
- fix for gcc 4.1.x
* Tue Jul 26 2005 kkaempf@suse.de
- update to 2.2.2, lots of small fixes.
* Thu Jan 20 2005 kkaempf@suse.de
- update to 2.2.1
- security fix and better error checking in socket handling
- RouteToGateway command for virtual queue routing (out-of-zone routing)
- race condition in config reload fixed
- changed default for RTPPortRange in proxy mode
- for flexible rewrite rules and prefix matching with '.' and '%%'
  wildcards
- per call proxy control
- new TcpKeepAlive option to remove problem with network errors
  and hanging calls
- additional accounting variable for original destination number
* Tue Dec 21 2004 kkaempf@suse.de
- update to 2.2.0
- compile with exceptions enabled
* Thu Aug 19 2004 kkaempf@suse.de
- update to 2.2beta4
* Mon Mar  8 2004 ro@suse.de
- added libdc1394-devel to neededforbuild
* Tue Feb 24 2004 kkaempf@suse.de
- and ppc64 and s930 need the 64bit patch too
* Mon Feb 23 2004 kkaempf@suse.de
- ia64 is 64bit (and needs the 64bit patch ;-))
* Sun Feb 22 2004 ro@suse.de
- split patch into normal and 64bit part
* Sun Feb 22 2004 kkaempf@suse.de
- update to 2.2beta3
* Sun Feb 22 2004 ro@suse.de
- updated neededforbuild and make-flags
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Jul 22 2003 kkaempf@suse.de
- update to 2.0.5
  adapt to pwlib 1.5.x and openh323 1.12.x
* Fri Feb  7 2003 kkaempf@suse.de
- adapt to latest openh323 library.
* Sun Jan 26 2003 meissner@suse.de
- ppc64 support, cleaned up arch handling.
* Wed Jan 15 2003 kkaempf@suse.de
- update to 2.0.2
* Wed Nov 20 2002 kkaempf@suse.de
- add expat for VoiceXML support.
- update to 2.0.1
* Sat Aug 17 2002 kkaempf@suse.de
- Include ldap library to %%files section.
* Tue Aug  6 2002 kkaempf@suse.de
- Update to final 2.0a
- Rename to "gnugk" (see RELEASE-NOTES for details)
- Disable external password auth functionality for gcc 3.x
  as suggested on the openh323gk mailing list.
- Add PreReq to .spec file.
* Wed Jul 10 2002 kkaempf@suse.de
- Update to 2.0beta9
* Tue May 28 2002 sf@suse.de
- %%{_lib} fixes
* Tue May  7 2002 ro@suse.de
- make it compile with gcc-3.1 (compose1 is not in std::)
* Mon Feb 25 2002 kkaempf@suse.de
- properly update from START_* to insserv (#13206).
* Mon Feb  4 2002 kkaempf@suse.de
- Update to 1.0 (final).
- Remove rc.config and START_ variable from rc script.
* Fri Aug 17 2001 kkaempf@suse.de
- renamed to openh323gk
  the OpenH323 project now has it's own gatekeeper named 'opengk'
* Thu Aug 16 2001 kkaempf@suse.de
- implement RPM_BUILD_ROOT in spec file.
* Thu Aug  9 2001 kkaempf@suse.de
- update to 0.18
* Tue May 29 2001 kkaempf@suse.de
- update to 0.17
  search for gatekeeper.ini in /etc
  lsb compatible rcopengk script
* Wed Jan  3 2001 kkaempf@suse.de
- install directly to /usr/sbin
* Tue Nov 21 2000 kkaempf@suse.de
- fix filelist, more %%doc entries
* Mon Nov 20 2000 kkaempf@suse.de
- fix neededforbuild
  provide wrapper script
* Mon Nov 20 2000 kkaempf@suse.de
- use %%doc in spec file
* Fri Jul 14 2000 kkaempf@suse.de
- adapted to current openh323 library interface
* Thu Jul 13 2000 kkaempf@suse.de
- fix Summary
* Wed Jul 12 2000 kkaempf@suse.de
- fix sparc machtype, add ia64
* Mon Jul  3 2000 kkaempf@suse.de
- created package
